==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/IdentityUserFlow.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Optional;

import odata.msgraph.client.beta.enums.UserFlowType;

@JsonPropertyOrder({
    "@odata.type", 
    "userFlowType", 
    "userFlowTypeVersion"})
@JsonInclude(Include.NON_NULL)
public class IdentityUserFlow extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.identityUserFlow";
    }

    @JsonProperty("userFlowType")
    protected UserFlowType userFlowType;

    @JsonProperty("userFlowTypeVersion")
    protected Float userFlowTypeVersion;

    protected IdentityUserFlow() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderIdentityUserFlow() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private UserFlowType userFlowType;
        private Float userFlowTypeVersion;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder userFlowType(UserFlowType userFlowType) {
            this.userFlowType = userFlowType;
            this.changedFields = changedFields.add("userFlowType");
            return this;
        }

        public Builder userFlowTypeVersion(Float userFlowTypeVersion) {
            this.userFlowTypeVersion = userFlowTypeVersion;
            this.changedFields = changedFields.add("userFlowTypeVersion");
            return this;
        }

        public IdentityUserFlow build() {
            IdentityUserFlow _x = new IdentityUserFlow();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.identityUserFlow";
            _x.id = id;
            _x.userFlowType = userFlowType;
            _x.userFlowTypeVersion = userFlowTypeVersion;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    @Property(name="userFlowType")
    @JsonIgnore
    public Optional<UserFlowType> getUserFlowType() {
        return Optional.ofNullable(userFlowType);
    }

    public IdentityUserFlow withUserFlowType(UserFlowType userFlowType) {
        IdentityUserFlow _x = _copy();
        _x.changedFields = changedFields.add("userFlowType");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.identityUserFlow");
        _x.userFlowType = userFlowType;
        return _x;
    }

    @Property(name="userFlowTypeVersion")
    @JsonIgnore
    public Optional<Float> getUserFlowTypeVersion() {
        return Optional.ofNullable(userFlowTypeVersion);
    }

    public IdentityUserFlow withUserFlowTypeVersion(Float userFlowTypeVersion) {
        IdentityUserFlow _x = _copy();
        _x.changedFields = changedFields.add("userFlowTypeVersion");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.identityUserFlow");
        _x.userFlowTypeVersion = userFlowTypeVersion;
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public IdentityUserFlow patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        IdentityUserFlow _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public IdentityUserFlow put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        IdentityUserFlow _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private IdentityUserFlow _copy() {
        IdentityUserFlow _x = new IdentityUserFlow();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.userFlowType = userFlowType;
        _x.userFlowTypeVersion = userFlowTypeVersion;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("IdentityUserFlow[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("userFlowType=");
        b.append(this.userFlowType);
        b.append(", ");
        b.append("userFlowTypeVersion=");
        b.append(this.userFlowTypeVersion);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/entity/IdentityUserFlow.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Float;
import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Optional;

import odata.msgraph.client.beta.enums.UserFlowType;

@JsonPropertyOrder({
    "@odata.type", 
    "userFlowType", 
    "userFlowTypeVersion"})
@JsonInclude(Include.NON_NULL)
public class IdentityUserFlow extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.identityUserFlow";
    }

    @JsonProperty("userFlowType")
    protected UserFlowType userFlowType;

    @JsonProperty("userFlowTypeVersion")
    protected Float userFlowTypeVersion;

    protected IdentityUserFlow() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderIdentityUserFlow() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private UserFlowType userFlowType;
        private Float userFlowTypeVersion;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder userFlowType(UserFlowType userFlowType) {
            this.userFlowType = userFlowType;
            this.changedFields = changedFields.add("userFlowType");
            return this;
        }

        public Builder userFlowTypeVersion(Float userFlowTypeVersion) {
            this.userFlowTypeVersion = userFlowTypeVersion;
            this.changedFields = changedFields.add("userFlowTypeVersion");
            return this;
        }

        public IdentityUserFlow build() {
            IdentityUserFlow _x = new IdentityUserFlow();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.identityUserFlow";
            _x.id = id;
            _x.userFlowType = userFlowType;
            _x.userFlowTypeVersion = userFlowTypeVersion;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    @Property(name="userFlowType")
    @JsonIgnore
    public Optional<UserFlowType> getUserFlowType() {
        return Optional.ofNullable(userFlowType);
    }

    public IdentityUserFlow withUserFlowType(UserFlowType userFlowType) {
        IdentityUserFlow _x = _copy();
        _x.changedFields = changedFields.add("userFlowType");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.identityUserFlow");
        _x.userFlowType = userFlowType;
        return _x;
    }

    @Property(name="userFlowTypeVersion")
    @JsonIgnore
    public Optional<Float> getUserFlowTypeVersion() {
        return Optional.ofNullable(userFlowTypeVersion);
    }

    public IdentityUserFlow withUserFlowTypeVersion(Float userFlowTypeVersion) {
        IdentityUserFlow _x = _copy();
        _x.changedFields = changedFields.add("userFlowTypeVersion");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.identityUserFlow");
        _x.userFlowTypeVersion = userFlowTypeVersion;
        return _x;
    }

    public IdentityUserFlow withUnmappedField(String name, Object value) {
        IdentityUserFlow _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public IdentityUserFlow patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        IdentityUserFlow _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public IdentityUserFlow put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        IdentityUserFlow _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private IdentityUserFlow _copy() {
        IdentityUserFlow _x = new IdentityUserFlow();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.userFlowType = userFlowType;
        _x.userFlowTypeVersion = userFlowTypeVersion;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("IdentityUserFlow[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("userFlowType=");
        b.append(this.userFlowType);
        b.append(", ");
        b.append("userFlowTypeVersion=");
        b.append(this.userFlowTypeVersion);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
